import { ElementRef } from '@angular/core';
import { List } from '../list/list';
/**
 * @name ItemSliding
 *
 * @description
 * Creates a list-item that can easily be swiped, deleted, reordered, edited, and more.
 *
 * @usage
 * ```html
 * <ion-list>
 *   <ion-item-sliding *ngFor="let item of items">
 *     <button ion-item (click)="itemTapped(item)">
 *       {% raw %}{{item.title}}{% endraw %}
 *     </button>
 *     <ion-item-options>
 *       <button (click)="favorite(item)">Favorite</button>
 *       <button (click)="share(item)">Share</button>
 *     </ion-item-options>
 *   </ion-item-sliding>
 * </ion-list>
 * ```
 * ItemSliding can be closed by API by adding #slidingItem in ion-item-sliding.
 * We grab a reference to the item reference by pass the `#slidingItem` to the share method.
 *
 * ```html
 * <ion-list>
 *   <ion-item-sliding *ngFor="#item of items" #slidingItem>
 *     <button ion-item (click)="itemTapped(item)">
 *       {% raw %}{{item}}{% endraw %}
 *   </button>
 *     <ion-item-options>
 *       <button (click)="share(item, slidingItem)">Share</button>
 *     </ion-item-options>
 *   </ion-item-sliding>
 * </ion-list>
 * ```
 *
 * ```typescript
 * share(item, slidingItem) {
 *    slidingItem.close();
 * }
 * ```
 *
 * @demo /docs/v2/demos/item-sliding/
 * @see {@link /docs/v2/components#lists List Component Docs}
 * @see {@link ../../list/List List API Docs}
 */
export declare class ItemSliding {
    private _list;
    constructor(_list: List, elementRef: ElementRef);
    /**
     * @private
     */
    close(): void;
}
